import json
import requests


def load_carto_credentials(filepath):
    """Load credentials from file. It must contain the following attributes:
    - api_base_url
    - client_id
    - client_secret
    """
    with open(filepath, "r") as f:
        content = json.load(f)

    if "api_base_url" not in content:
        raise Exception("Missing attribute 'api_base_url'")

    if "client_id" not in content:
        raise Exception("Missing attribute 'client_id'")

    if "client_secret" not in content:
        raise Exception("Missing attribute 'client_secret'")

    url = "https://auth.carto.com/oauth/token"
    headers = {"Content-Type": "application/x-www-form-urlencoded"}
    data = {
        "grant_type": "client_credentials",
        "audience": "carto-cloud-native-api",
        "client_id": content["client_id"],
        "client_secret": content["client_secret"],
    }
    response = requests.post(url, headers=headers, data=data)
    oauth_token = response.json()["access_token"]

    return {
        "apiVersion": "v3",
        "apiBaseUrl": content["api_base_url"],
        "accessToken": oauth_token,
    }



import pydeck as pdk

CARTO_LAYER_BUNDLE_URL = "https://libs.cartocdn.com/pydeck/@deck.gl/carto@8.7.8/dist.min.js"


def register_carto_layer():
    """Add CartoLayer JS bundle to pydeck"s custom libraries"""
    library_name = "CartoLayerLibrary"
    custom_library = {
        "libraryName": library_name,
        "resourceUri": CARTO_LAYER_BUNDLE_URL,
    }

    if pdk.settings.custom_libraries is None:
        pdk.settings.custom_libraries = [custom_library]
        return

    exists = any(
        [x.get("libraryName") == library_name for x in pdk.settings.custom_libraries]
    )

    if not exists:
        pdk.settings.custom_libraries.append(custom_library)
